==> jc-1.4.0.tar.gz: java/security/spec/RSAMultiPrimePrivateCrtKeySpec.h <==
// public class java.security.spec.RSAMultiPrimePrivateCrtKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce6d1fa68d092edb java_security_spec_RSAMultiPrimePrivateCrtKeySpec
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_security_spec_RSAPrivateKeySpec

#include "java/security/spec/RSAPrivateKeySpec.h"

#ifndef _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_
#define _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object;

typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$_init$cd830e2dd8c638cd(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern _jc_object_array *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getOtherPrimeInfo$32ea80d86c785e49(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeExponentP$7b86450f402ae888(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeExponentQ$1768ae9fab37aad8(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeP$9033505b0ccf417d(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeQ$bf448ca4ce4c7a9b(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getOtherPrimeInfo$32ea80d86c785e49;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeExponentP$7b86450f402ae888;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeExponentQ$1768ae9fab37aad8;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeP$9033505b0ccf417d;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeQ$bf448ca4ce4c7a9b;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	_jc_object_array	*(*getOtherPrimeInfo$32ea80d86c785e49)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentP$7b86450f402ae888)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentQ$1768ae9fab37aad8)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeP$9033505b0ccf417d)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeQ$bf448ca4ce4c7a9b)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
	struct _jc_java_math_BigInteger$object	*primeP;
	struct _jc_java_math_BigInteger$object	*primeQ;
	struct _jc_java_math_BigInteger$object	*primeExponentP;
	struct _jc_java_math_BigInteger$object	*primeExponentQ;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
	_jc_object_array	*otherPrimeInfo;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs {
    _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object {
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAMultiPrimePrivateCrtKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAMultiPrimePrivateCrtKeySpec.h <==
// public class java.security.spec.RSAMultiPrimePrivateCrtKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce6d1fa68d092edb java_security_spec_RSAMultiPrimePrivateCrtKeySpec
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_security_spec_RSAPrivateKeySpec

#include "java/security/spec/RSAPrivateKeySpec.h"

#ifndef _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_
#define _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object;

typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$_init$cd830e2dd8c638cd(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getOtherPrimeInfo$32ea80d86c785e49(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeExponentP$7b86450f402ae888(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeExponentQ$1768ae9fab37aad8(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeP$9033505b0ccf417d(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPrimeQ$bf448ca4ce4c7a9b(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getOtherPrimeInfo$32ea80d86c785e49;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeExponentP$7b86450f402ae888;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeExponentQ$1768ae9fab37aad8;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeP$9033505b0ccf417d;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPrimeQ$bf448ca4ce4c7a9b;
extern _jc_method _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getOtherPrimeInfo$32ea80d86c785e49)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentP$7b86450f402ae888)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentQ$1768ae9fab37aad8)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeP$9033505b0ccf417d)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeQ$bf448ca4ce4c7a9b)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vmethods	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
	struct _jc_java_math_BigInteger$object	*primeP;
	struct _jc_java_math_BigInteger$object	*primeQ;
	struct _jc_java_math_BigInteger$object	*primeExponentP;
	struct _jc_java_math_BigInteger$object	*primeExponentQ;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
	_jc_object_array	*otherPrimeInfo;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs {
    _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_refs	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$sub_nonrefs	java_security_spec_RSAMultiPrimePrivateCrtKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$object {
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$vtype _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAMultiPrimePrivateCrtKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAMultiPrimePrivateCrtKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAMultiPrimePrivateCrtKeySpec_H_ */
